@@ -21,8 +21,8 @@
 #include "fitsview.h"
 #include "fitsimage.h"
 
-#include <math.h>
-#include <stdlib.h>
+#include <cmath>
+#include <cstdlib>
 
 #include <QPainter>
 #include <QSlider>
