@@ -47,7 +47,7 @@ public:
      * Constructor.
      *@param jd  Julian Day for which the new instance is initialized
      */
-    KSNumbers( long double jd );
+    explicit KSNumbers( long double jd );
 
     /**Destructor (empty). */
     ~KSNumbers();
